#!/usr/bin/env python3
# Ubuntu CI Engine
# Copyright 2014 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from oauthlib.common import (
    generate_client_id,
    generate_token,
)
from textwrap import dedent
from argparse import ArgumentParser

from nfdc import database


def main():
    parser = ArgumentParser('nfdc')
    subparsers = parser.add_subparsers(help='Commands', dest="command")

    parser_keys_add = subparsers.add_parser(
        'keys-add',
        help="Generate a new set of access keys.",
    )
    parser_keys_del = subparsers.add_parser(
        'keys-del',
        help="Remove an existing set of access keys.",
    )
    parser_db_migrate = subparsers.add_parser(
        'database-migrate',
        help="Migrate the database.",
    )
    arguments = parser.parse_args()
    if arguments.command is None:
        parser.error("Missing command string.")
        return

    if arguments.command == 'keys-add':
        keys_add()


def keys_add():
    repeat = True
    name = description = poc = ""
    while repeat:
        name = input("Client name: ")
        poc = input("Point of contact (name & email address): ")
        description = input("Description of client: ")
        print(
            dedent(
                """
                Client Summary:

                Client Name: {}
                Point of Contact: {}
                Description: {}

                """.format(name, poc, description)
            )
        )
        correct = input("Is this information correct (y/n)? ")
        repeat = correct.lower().strip() == "n"

    access_key = generate_token()
    owner_key = generate_token()
    owner_secret = generate_client_id()

    database_connection = database.get_connection_for_request()
    database.auth_add_client_details(
        database_connection,
        name,
        description,
        poc,
        access_key,
        owner_key,
        owner_secret
    )
    print("Access key is: %r" % access_key)
    print("Owner key is: %r" % owner_key)
    print("Owner secret is: %r" % owner_secret)


if __name__ == '__main__':
    main()
